@@ -63,6 +63,8 @@
 #include "policygeneration.h"
 #include "aureport.h"
 #include "ausearch.h"
+#include "useradd.h"
+#include "seeprocess.h"
 #include "mainwindow.h"
 
 MainWindow::MainWindow(QWidget *parent, const char *name)
@@ -106,6 +108,8 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	policygeneration_process_o = 0;
 	aureport_o = 0;
 	ausearch_o = 0;
+	useradd_o = 0;
+	seeprocess_o = 0;
 
 	//connect SIGNAL to objects    
 
@@ -121,7 +125,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	createToolBars();
 	createStatusBar();
 
-	setCaption(tr("segatex-5.60"));
+	setCaption(tr("segatex-6.10"));
 	setIcon(QPixmap::fromMimeSource("icon.png"));
 }
 
@@ -470,6 +474,16 @@ void MainWindow::createActions()
 	aureportAct->setStatusTip(tr("Ausearch"));
 	connect(ausearchAct, SIGNAL(activated()), this, SLOT(ausearch()));
 	connect(ausearchAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	useraddAct = new QAction(tr("&Useradd/delete"), 0, this);
+	useraddAct->setStatusTip(tr("useradd/delete"));
+	connect(useraddAct, SIGNAL(activated()), this, SLOT(useradd()));
+	connect(useraddAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	seeprocessAct = new QAction(tr("&see process"), 0, this);
+	seeprocessAct->setStatusTip(tr("see process"));
+	connect(seeprocessAct, SIGNAL(activated()), this, SLOT(seeprocess()));
+	connect(seeprocessAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 }
 
 void MainWindow::createMenus()
@@ -557,6 +571,10 @@ void MainWindow::createMenus()
 	autorelabelMenu = new QPopupMenu(this);
 	autorelabel_processAct->addTo(autorelabelMenu);
 
+	miscellaneousMenu = new QPopupMenu(this);
+	useraddAct->addTo(miscellaneousMenu);
+	seeprocessAct->addTo(miscellaneousMenu);
+
 	menuBar()->insertItem(tr("&File"), fileMenu);
 	menuBar()->insertItem(tr("&Edit"), editMenu);
 	menuBar()->insertItem(tr("&Windows"), windowsMenu);
@@ -576,6 +594,9 @@ void MainWindow::createMenus()
 	menuBar()->insertSeparator();
 	menuBar()->insertItem(tr("Re&label"), autorelabelMenu);
 
+	menuBar()->insertSeparator();
+	menuBar()->insertItem(tr("Mis&c"), miscellaneousMenu);
+
 	menuBar()->insertSeparator();
 	menuBar()->insertItem(tr("&Help"), helpMenu);
 }
@@ -911,7 +932,7 @@ void MainWindow::notice()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-5.60</h2>"
+		tr("<h2>segatex-6.10</h2>"
 		"<p>Copyright &copy; 2007-2008"
 		"<p>Shintaro Fujiwara."
 		"<p>segatex is a SELinux tool"
@@ -1042,7 +1063,12 @@ void MainWindow::enforcing()
 		segatex_apply = new SegatexApply(this);
 		connect(segatex_apply, SIGNAL(enforcingOn()), segatex_apply, SLOT(setenforce_enforcing())); 
 		connect(segatex_apply, SIGNAL(permissiveOn()), segatex_apply, SLOT(setenforce_permissive())); 
-		//connect(segatex_apply, SIGNAL(disabledOn()), segatex_apply, SLOT(setenforce_disabled())); 
+//for test
+		connect(segatex_apply, SIGNAL(permissiveOn()), this, SLOT(updateSegatexStateIndicator()));
+		connect(segatex_apply, SIGNAL(enforcingOn()), this, SLOT(updateSegatexStateIndicator()));
+//end for test
+		connect(segatex_apply, SIGNAL(disabledOn()), segatex_apply, SLOT(setenforce_disabled())); 
+		connect(previousAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 	}
 	segatex_apply->show();
 	segatex_apply->raise();
@@ -1185,3 +1211,21 @@ void MainWindow::ausearch()
 	ausearch_o->raise();
 	ausearch_o->setActiveWindow();
 }
+void MainWindow::useradd()
+{
+	if(!useradd_o) {
+		useradd_o = new Useradd(this);
+	}
+	useradd_o->show();
+	useradd_o->raise();
+	useradd_o->setActiveWindow();
+}
+void MainWindow::seeprocess()
+{
+	if(!seeprocess_o) {
+		seeprocess_o = new Seeprocess(this);
+	}
+	seeprocess_o->show();
+	seeprocess_o->raise();
+	seeprocess_o->setActiveWindow();
+}
