@@ -60,6 +60,8 @@ class AutoRelabel;
 class Policygeneration;
 class Aureport;
 class Ausearch;
+class Useradd;
+class Seeprocess;
 
 class MainWindow : public QMainWindow
 {
@@ -118,6 +120,8 @@ private slots:
     void policygeneration_process();
     void aureport();
     void ausearch();
+    void useradd();
+    void seeprocess();
 
     void save();
     void saveAs();
@@ -190,6 +194,8 @@ private:
     Policygeneration *policygeneration_process_o;
     Aureport *aureport_o;
     Ausearch *ausearch_o;
+    Useradd *useradd_o;
+    Seeprocess *seeprocess_o;
     
     QPopupMenu *fileMenu;
     QPopupMenu *editMenu;
@@ -204,6 +210,7 @@ private:
     QPopupMenu *manageMenu;
     QPopupMenu *semanageMenu;
     QPopupMenu *autorelabelMenu;
+    QPopupMenu *miscellaneousMenu;
 
     QToolBar *fileToolBar;
     QToolBar *editToolBar;
@@ -266,6 +273,8 @@ private:
     QAction *policygeneration_processAct;
     QAction *aureportAct;
     QAction *ausearchAct;
+    QAction *useraddAct;
+    QAction *seeprocessAct;
 };
 
 #endif
