@@ -291,18 +291,7 @@ lines_break.gres(" socket_class_set","{ tcp_socket udp_socket rawip_socket netli
 lines_break.gres(" dgram_socket_class_set","{ udp_socket unix_dgram_socket }");
 lines_break.gres(" stream_socket_class_set","{ tcp_socket unix_stream_socket }");
 lines_break.gres(" unpriv_socket_class_set","{ tcp_socket udp_socket unix_stream_socket unix_dgram_socket }");
-lines_break.gres(" stat_file_perms","{ getattr }");
-lines_break.gres(" x_file_perms","{ getattr execute }");
-lines_break.gres(" r_file_perms","{ read getattr lock ioctl }");
-lines_break.gres(" rx_file_perms","{ read getattr lock execute ioctl }");
-lines_break.gres(" ra_file_perms","{ ioctl read getattr lock append }");
-lines_break.gres(" link_file_perms","{ getattr link unlink rename }");
-lines_break.gres(" create_lnk_perms","{ create read getattr setattr link unlink rename }");
-lines_break.gres(" create_file_perms","{ create ioctl read getattr lock write setattr append link unlink rename }");
-lines_break.gres(" r_dir_perms","{ read getattr lock search ioctl }");
 lines_break.gres(" rw_dir_perms","{ read getattr lock search ioctl add_name remove_name write }");
-lines_break.gres(" ra_dir_perms","{ read getattr lock search ioctl add_name write }");
-lines_break.gres(" create_dir_perms","{ create read getattr lock setattr ioctl link unlink rename search add_name remove_name reparent write rmdir }");
 lines_break.gres(" mount_fs_perms","{ mount remount unmount getattr }");
 lines_break.gres(" rw_socket_perms","{ ioctl read getattr write setattr append bind connect getopt setopt shutdown }");
 lines_break.gres(" create_socket_perms","{ create rw_socket_perms }");
@@ -340,7 +329,7 @@ lines_break.gres(" relabel_dir_perms","{ getattr relabelfrom relabelto }");
 lines_break.gres(" getattr_file_perms","{ getattr }");
 lines_break.gres(" setattr_file_perms","{ setattr }");
 lines_break.gres(" read_file_perms","{ getattr read lock ioctl }");
-lines_break.gres(" mmap_file_perms","{ getattr read execute }");
+lines_break.gres(" mmap_file_perms","{ getattr read execute ioctl }");
 lines_break.gres(" exec_file_perms","{ getattr read execute execute_no_trans }");
 lines_break.gres(" append_file_perms","{ getattr append lock ioctl }");
 lines_break.gres(" write_file_perms","{ getattr write append lock ioctl }");
@@ -555,16 +544,7 @@ lines_break.gres(" socket_class_set","{ tcp_socket udp_socket rawip_socket netli
 lines_break.gres(" dgram_socket_class_set","{ udp_socket unix_dgram_socket }");
 lines_break.gres(" stream_socket_class_set","{ tcp_socket unix_stream_socket }");
 lines_break.gres(" unpriv_socket_class_set","{ tcp_socket udp_socket unix_stream_socket unix_dgram_socket }");
-lines_break.gres(" stat_file_perms","{ getattr }");
-lines_break.gres(" x_file_perms","{ getattr execute }");
-lines_break.gres(" r_file_perms","{ read getattr lock ioctl }");
-lines_break.gres(" rx_file_perms","{ read getattr lock execute ioctl }");
-lines_break.gres(" ra_file_perms","{ ioctl read getattr lock append }");
-lines_break.gres(" link_file_perms","{ getattr link unlink rename }");
-lines_break.gres(" create_lnk_perms","{ create read getattr setattr link unlink rename }");
-lines_break.gres(" r_dir_perms","{ read getattr lock search ioctl }");
 lines_break.gres(" rw_dir_perms","{ read getattr lock search ioctl add_name remove_name write }");
-lines_break.gres(" ra_dir_perms","{ read getattr lock search ioctl add_name write } ");
 lines_break.gres(" mount_fs_perms","{ mount remount unmount getattr }");
 lines_break.gres(" rw_socket_perms","{ ioctl read getattr write setattr append bind connect getopt setopt shutdown }");
 lines_break.gres(" create_socket_perms","{ create rw_socket_perms }");
@@ -602,7 +582,7 @@ lines_break.gres(" relabel_dir_perms","{ getattr relabelfrom relabelto }");
 lines_break.gres(" getattr_file_perms","{ getattr }");
 lines_break.gres(" setattr_file_perms","{ setattr }");
 lines_break.gres(" read_file_perms","{ getattr read lock ioctl }");
-lines_break.gres(" mmap_file_perms","{ getattr read execute }");
+lines_break.gres(" mmap_file_perms","{ getattr read execute ioctl }");
 lines_break.gres(" exec_file_perms","{ getattr read execute execute_no_trans }");
 lines_break.gres(" append_file_perms","{ getattr append lock ioctl }");
 lines_break.gres(" write_file_perms","{ getattr write append lock ioctl }");
@@ -778,16 +758,7 @@ lines_break.gres(" socket_class_set","{ tcp_socket udp_socket rawip_socket netli
 lines_break.gres(" dgram_socket_class_set","{ udp_socket unix_dgram_socket }");
 lines_break.gres(" stream_socket_class_set","{ tcp_socket unix_stream_socket }");
 lines_break.gres(" unpriv_socket_class_set","{ tcp_socket udp_socket unix_stream_socket unix_dgram_socket }");
-lines_break.gres(" stat_file_perms","{ getattr }");
-lines_break.gres(" x_file_perms","{ getattr execute }");
-lines_break.gres(" r_file_perms","{ read getattr lock ioctl }");
-lines_break.gres(" rx_file_perms","{ read getattr lock execute ioctl }");
-lines_break.gres(" ra_file_perms","{ ioctl read getattr lock append }");
-lines_break.gres(" link_file_perms","{ getattr link unlink rename }");
-lines_break.gres(" create_lnk_perms","{ create read getattr setattr link unlink rename }");
-lines_break.gres(" r_dir_perms","{ read getattr lock search ioctl }");
 lines_break.gres(" rw_dir_perms","{ read getattr lock search ioctl add_name remove_name write }");
-lines_break.gres(" ra_dir_perms","{ read getattr lock search ioctl add_name write } ");
 lines_break.gres(" mount_fs_perms","{ mount remount unmount getattr }");
 lines_break.gres(" rw_socket_perms","{ ioctl read getattr write setattr append bind connect getopt setopt shutdown }");
 lines_break.gres(" create_socket_perms","{ create rw_socket_perms }");
@@ -825,7 +796,7 @@ lines_break.gres(" relabel_dir_perms","{ getattr relabelfrom relabelto }");
 lines_break.gres(" getattr_file_perms","{ getattr }");
 lines_break.gres(" setattr_file_perms","{ setattr }");
 lines_break.gres(" read_file_perms","{ getattr read lock ioctl }");
-lines_break.gres(" mmap_file_perms","{ getattr read execute }");
+lines_break.gres(" mmap_file_perms","{ getattr read execute ioctl }");
 lines_break.gres(" exec_file_perms","{ getattr read execute execute_no_trans }");
 lines_break.gres(" append_file_perms","{ getattr append lock ioctl }");
 lines_break.gres(" write_file_perms","{ getattr write append lock ioctl }");
