@@ -101,6 +101,22 @@
         <source>close</source>
         <translation type="unfinished">閉じる</translation>
     </message>
+    <message>
+        <source>start-day(1/1/2008)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>start-time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>end-day</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>end-time</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AureportProcess</name>
@@ -145,7 +161,7 @@
     </message>
     <message>
         <source>effective group ID (effective-group-id)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">実効的グループID</translation>
     </message>
     <message>
         <source>group ID (group-id)</source>
@@ -161,7 +177,7 @@
     </message>
     <message>
         <source>key string (key-string)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">キーストリング</translation>
     </message>
     <message>
         <source>node (node-name)</source>
@@ -191,6 +207,22 @@
         <source>Interpret numeric entities into text</source>
         <translation type="unfinished">数字要素を文字列に変換</translation>
     </message>
+    <message>
+        <source>start-time</source>
+        <translation type="unfinished">開始時間</translation>
+    </message>
+    <message>
+        <source>end-day</source>
+        <translation type="unfinished">終了日</translation>
+    </message>
+    <message>
+        <source>end-time</source>
+        <translation type="unfinished">終了時間</translation>
+    </message>
+    <message>
+        <source>start-day(1/1/2008)</source>
+        <translation type="unfinished">開始日(2008年01月01日)</translation>
+    </message>
 </context>
 <context>
     <name>AusearchProcess</name>
@@ -394,7 +426,7 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>Del</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">削除</translation>
     </message>
     <message>
         <source>Delete the current selection</source>
@@ -446,7 +478,7 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>Move the focus to the next window</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">次のウィンドウにフォーカスする</translation>
     </message>
     <message>
         <source>Pre&amp;vious</source>
@@ -458,7 +490,7 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>Move the focus to the previous window</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">前のウィンドウにフォーカスを当てる</translation>
     </message>
     <message>
         <source>&amp;About</source>
@@ -482,103 +514,103 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>Parse .if files in admin layer</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Adminレイヤーファイルの分解準備</translation>
     </message>
     <message>
         <source>Parse A&amp;pps</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Appsレイヤーファイルの分解準備</translation>
     </message>
     <message>
         <source>Parse .if files in apps layer</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Appsレイヤーファイルの分解準備</translation>
     </message>
     <message>
         <source>Parse &amp;Kernel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Kernelレイヤーファイルの分解準備</translation>
     </message>
     <message>
         <source>Parse .if files in kernel layer</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Kernelレイヤーファイルの分解準備</translation>
     </message>
     <message>
         <source>Parse &amp;Services</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Servicesレイヤーファイルの分解準備</translation>
     </message>
     <message>
         <source>Parse .if files in services layer</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Servicesレイヤーファイルの分解準備</translation>
     </message>
     <message>
         <source>Parse S&amp;ystem</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Systemレイヤーファイルの分解準備</translation>
     </message>
     <message>
         <source>Parse .if files in system layer</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Systemレイヤーファイルの分解準備</translation>
     </message>
     <message>
         <source>&amp;Obj perm sets</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Obj perm setsファイルの分解準備</translation>
     </message>
     <message>
         <source>Parse obj_perm_sets file</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Obj perm setsファイルの分解準備</translation>
     </message>
     <message>
         <source>&amp;Ipc patterns</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Ipcパターンファイルの分解準備</translation>
     </message>
     <message>
         <source>Parse ipc patterns file</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Ipcパターンファイルの分解準備</translation>
     </message>
     <message>
         <source>&amp;Misc patterns</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Miscパターンファイルの分解準備</translation>
     </message>
     <message>
         <source>Parse misc patterns file</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Miscパターンファイルの分解準備</translation>
     </message>
     <message>
         <source>Break &amp;Admin</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Adminレイヤーファイルの分解</translation>
     </message>
     <message>
         <source>Break .if files in admin layer</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Adminレイヤーファイルの分解</translation>
     </message>
     <message>
         <source>Break A&amp;pps</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Appsレイヤーファイルの分解</translation>
     </message>
     <message>
         <source>Break .if files in apps layer</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Appsレイヤーファイルの分解</translation>
     </message>
     <message>
         <source>Break &amp;Kernel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Kernelレイヤーファイルの分解</translation>
     </message>
     <message>
         <source>Break .if files in kernel layer</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Kernelレイヤーファイルの分解</translation>
     </message>
     <message>
         <source>Break &amp;Services</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Servicesレイヤーファイルの分解</translation>
     </message>
     <message>
         <source>Break .if files in services layer</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Servicesレイヤーファイルの分解</translation>
     </message>
     <message>
         <source>Break S&amp;ystem</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Systemレイヤーファイルの分解</translation>
     </message>
     <message>
         <source>Break .if files in system layer</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Systemレイヤーファイルの分解</translation>
     </message>
     <message>
         <source>Selpaw &amp;Admin</source>
@@ -750,7 +782,7 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>semanage &amp;translation</source>
-        <translation type="unfinished">レベル変換を変数</translation>
+        <translation type="unfinished">レベル変換を編集</translation>
     </message>
     <message>
         <source>Semanage translation -a -m -d.</source>
@@ -758,7 +790,7 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>setse&amp;bool </source>
-        <translation type="unfinished">ボーリアン切り替え</translation>
+        <translation type="unfinished">ブーリアン切り替え</translation>
     </message>
     <message>
         <source>setsebool [-P] boolean value.</source>
@@ -870,7 +902,7 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>&lt;h2&gt;How to use segatex&lt;/h2&gt;&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex]&lt;/font&gt;&lt;p&gt;You can set selinux enforcing and permissive just pushing button. You can install/update SELinux related RPMs.You can audit2allow You can analize audit log. You can manage modules. You can semanage. You can setsebool. You can relabel the system. You can generate brand-new policy module. You can generate interfaced policy,by  Analize audit.log-generate policy. You can aureport. You can ausearch.&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex_editor]&lt;/font&gt;&lt;p&gt;Push Parselines,Selpaw,Refine one by one orderly.&lt;p&gt;If you could get three selpaw files,i.e.selpaw_interface.csv,selpaw_interface_types.csv,selpaw_interface_summary.csv, that is a success.&lt;p&gt;Break kernel may take 30 minutes, and Refine selpaw takes 10 minutes;)&lt;/p&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&lt;h2&gt;segatexの使用法&lt;/h2&gt;&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex]&lt;/font&gt;&lt;p&gt;ボタンを押すだけでSELinuxのモードを切り替えられます。SELinux関連のパッケージをインストール/アップデート出来ます。ログからポリシを生成できます。モジュールを操作できます。SELinuxの設定ができます。ブーリアンを切り替えられます。システムのラベルを付け直せます。独自ポリシもジュールを生成できます。Refpolicyの形式でポリシを生成できます。ログを検索したり、レポートを生成したりできます。&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex_editor]&lt;/font&gt;&lt;p&gt;分解準備-分解ボタンを順番に押して行って下さい。&lt;p&gt; ３つのselpaw files、すなわち、selpaw_interface.csv,selpaw_interface_types.csv,selpaw_interface_summary.csvが生成されれば成功です。&lt;p&gt;カーネルレイヤーファイルの分解には30分はかかります。Refine selpaw takes 10 minutes;)&lt;/p&gt;</translation>
     </message>
     <message>
         <source>%1 %2</source>
@@ -894,11 +926,71 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>segatex-5.50</source>
-        <translation type="unfinished">segatexバージョン5.50</translation>
+        <translation type="obsolete">segatexバージョン5.50</translation>
     </message>
     <message>
         <source>&lt;h2&gt;segatex-5.50&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
-        <translation type="unfinished">&lt;h2&gt;segatex-5.50&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
+        <translation type="obsolete">&lt;h2&gt;segatex-5.50&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
+    </message>
+    <message>
+        <source>segatex-5.70</source>
+        <translation type="obsolete">segatexバージョン5.70</translation>
+    </message>
+    <message>
+        <source>&lt;h2&gt;segatex-5.70&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
+        <translation type="obsolete">&lt;h2&gt;segatex-5.70&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
+    </message>
+    <message>
+        <source>segatex-5.80</source>
+        <translation type="obsolete">segatexバージョン5.80</translation>
+    </message>
+    <message>
+        <source>&lt;h2&gt;segatex-5.80&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
+        <translation type="obsolete">&lt;h2&gt;segatex-5.80&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
+    </message>
+    <message>
+        <source>segatex-5.90</source>
+        <translation type="obsolete">segatexバージョン5.90</translation>
+    </message>
+    <message>
+        <source>&amp;Useradd</source>
+        <translation type="obsolete">新規ユーザの追加</translation>
+    </message>
+    <message>
+        <source>useradd</source>
+        <translation type="obsolete">新規ユーザの追加</translation>
+    </message>
+    <message>
+        <source>Mis&amp;c</source>
+        <translation type="unfinished">その他の機能</translation>
+    </message>
+    <message>
+        <source>&lt;h2&gt;segatex-5.90&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
+        <translation type="obsolete">&lt;h2&gt;segatex-5.90&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
+    </message>
+    <message>
+        <source>segatex-6.00</source>
+        <translation type="unfinished">segatexバージョン6.00</translation>
+    </message>
+    <message>
+        <source>&lt;h2&gt;segatex-6.00&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
+        <translation type="unfinished">&lt;h2&gt;segatex-6.00&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
+    </message>
+    <message>
+        <source>&amp;Useradd/delete</source>
+        <translation type="unfinished">ユーザの追加と削除</translation>
+    </message>
+    <message>
+        <source>useradd/delete</source>
+        <translation type="unfinished">ユーザの追加と削除</translation>
+    </message>
+    <message>
+        <source>&amp;see process</source>
+        <translation type="unfinished">プロセスを見る</translation>
+    </message>
+    <message>
+        <source>see process</source>
+        <translation type="unfinished">プロセスを見る</translation>
     </message>
 </context>
 <context>
@@ -966,6 +1058,47 @@ Do you want to save your changes?</source>
         <translation type="unfinished">メインウインドウをセッティングする</translation>
     </message>
 </context>
+<context>
+    <name>Seeprocess</name>
+    <message>
+        <source>see process</source>
+        <translation type="unfinished">プロセスを見る</translation>
+    </message>
+    <message>
+        <source>grep:</source>
+        <translation type="unfinished">検索:</translation>
+    </message>
+    <message>
+        <source></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>grep</source>
+        <translation type="unfinished">検索</translation>
+    </message>
+    <message>
+        <source>&amp;Close</source>
+        <translation type="unfinished">閉じる</translation>
+    </message>
+    <message>
+        <source>segatex alert</source>
+        <translation type="unfinished">segatexアラート</translation>
+    </message>
+    <message>
+        <source>No text given.
+Try again !</source>
+        <translation type="unfinished">文字列が入っていません。もう一度！</translation>
+    </message>
+    <message>
+        <source>useradd process had an error !</source>
+        <translation type="unfinished">ユーザ追加過程でエラーがありました！</translation>
+    </message>
+    <message>
+        <source>
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>SegatexApply</name>
     <message>
@@ -1021,15 +1154,15 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>Read from:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">読み込むファイル</translation>
     </message>
     <message>
         <source>Write to:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">書き出すファイル</translation>
     </message>
     <message>
         <source>Other options:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">その他のオプション</translation>
     </message>
     <message>
         <source>/var/log/audit/audit.log</source>
@@ -1041,27 +1174,27 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>read input only after the last reload</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">最後のリロードからの入力</translation>
     </message>
     <message>
         <source>generate refpolicy style output</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">レフポリシのスタイルで</translation>
     </message>
     <message>
         <source>explain genetated output</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">説明付き</translation>
     </message>
     <message>
         <source>fully explain genetated output</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">詳細な説明付き</translation>
     </message>
     <message>
         <source>Module Name( alphabet and numbers only &quot;_&quot; can&apos;t be used):</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">モジュール名（英数字のみ）</translation>
     </message>
     <message>
         <source>&amp;audit2allow</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ログからポリシ生成</translation>
     </message>
     <message>
         <source>&amp;Close</source>
@@ -1215,15 +1348,15 @@ Do you want to save your changes?</source>
     <name>SegatexYumProcess</name>
     <message>
         <source>Yum SELinux Process</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">SELinuxのYum過程</translation>
     </message>
     <message>
         <source>close</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">閉じる</translation>
     </message>
     <message>
         <source>yum install process ended !</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">yumインストール過程は終了しました！</translation>
     </message>
     <message>
         <source>
@@ -1232,195 +1365,195 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>yum install process had an error !</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">yumインストール過程でエラーが発生しました！</translation>
     </message>
     <message>
         <source>yum update process ended !</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">yumアップデート過程は終了しました！</translation>
     </message>
     <message>
         <source>yum update process had an error !</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">yumアップデート過程でエラーが発生しました！</translation>
     </message>
 </context>
 <context>
     <name>SemanageCoreBooleanProcess</name>
     <message>
         <source>Setsebool Process</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Setsebool過程</translation>
     </message>
     <message>
         <source>Boolean:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ブーリアン</translation>
     </message>
     <message>
         <source>temporary</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">一時的に</translation>
     </message>
     <message>
         <source>permanent</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">永久に</translation>
     </message>
     <message>
         <source>value{on|off}:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">値{on|off}</translation>
     </message>
     <message>
         <source>Set this boolean</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">このブーリアンをセットする</translation>
     </message>
     <message>
         <source>close</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">閉じる</translation>
     </message>
 </context>
 <context>
     <name>SemanageCoreFcontextProcess</name>
     <message>
         <source>Semanage Fcontext Process</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Semanage Fcontext過程</translation>
     </message>
     <message>
         <source>fcontext:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ファイルコンテキスト：</translation>
     </message>
     <message>
         <source>file_spec:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ファイルスペック：</translation>
     </message>
     <message>
         <source>range:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">レンジ：</translation>
     </message>
     <message>
         <source>Add</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">追加</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">削除</translation>
     </message>
     <message>
         <source>Modify</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">変更</translation>
     </message>
     <message>
         <source>all files</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">全てのファイル</translation>
     </message>
     <message>
         <source>regular file</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">通常ファイル</translation>
     </message>
     <message>
         <source>directory</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ディレクトリ</translation>
     </message>
     <message>
         <source>block device</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ブロックディバイス</translation>
     </message>
     <message>
         <source>character device</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">キャラクタディバイス</translation>
     </message>
     <message>
         <source>socket</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ソケット</translation>
     </message>
     <message>
         <source>symbolic link</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">シンボリックリンク</translation>
     </message>
     <message>
         <source>named pipe</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">名前付きパイプ</translation>
     </message>
     <message>
         <source>close</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">閉じる</translation>
     </message>
 </context>
 <context>
     <name>SemanageCoreLoginProcess</name>
     <message>
         <source>Semanage Login Process</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Semanage Login過程</translation>
     </message>
     <message>
         <source>Add Unix user:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ユーザを追加:</translation>
     </message>
     <message>
         <source>as a SELinux user:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">SELinuxユーザとして:</translation>
     </message>
     <message>
         <source>range:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">レンジ：</translation>
     </message>
     <message>
         <source>Add this user</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">このユーザを追加</translation>
     </message>
     <message>
         <source>Delete Unix user&apos;s mapping to SELinux user(Unix user&apos;s name):</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">UnixユーザのSELinuxユーザへのマッピングを削除(Unixユーザ名を入力):</translation>
     </message>
     <message>
         <source>Delete this user</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">このユーザを削除</translation>
     </message>
     <message>
         <source>Modify Unix user:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Unixユーザを変更</translation>
     </message>
     <message>
         <source>Modify this user</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">このユーザを変更</translation>
     </message>
     <message>
         <source>close</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">閉じる</translation>
     </message>
 </context>
 <context>
     <name>SemanageCorePortProcess</name>
     <message>
         <source>Semanage Port Process</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Semanage Port過程</translation>
     </message>
     <message>
         <source>Add port(port_type):</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ポートの追加(ポート):</translation>
     </message>
     <message>
         <source>protocol{tcp|udp}:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">プロトコル{tcp|udp}:</translation>
     </message>
     <message>
         <source>port_range:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ポートレンジ:</translation>
     </message>
     <message>
         <source>Add port</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ポートを追加</translation>
     </message>
     <message>
         <source>Delete port(port_type):</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ポートの削除(ポート):</translation>
     </message>
     <message>
         <source>Delete port</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ポートを削除</translation>
     </message>
     <message>
         <source>Modify port(port_type):</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ポートの変更(ポート):</translation>
     </message>
     <message>
         <source>Modify port</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ポートを変更</translation>
     </message>
     <message>
         <source>close</source>
@@ -1442,35 +1575,35 @@ Do you want to save your changes?</source>
     <name>SemanageCoreTranslationProcess</name>
     <message>
         <source>Semanage Translation Process</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Semanage Translation(変換)過程</translation>
     </message>
     <message>
         <source>Add translation(translation_name):</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">変換の追加(変換名):</translation>
     </message>
     <message>
         <source>level:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">レベル:</translation>
     </message>
     <message>
         <source>Add translation</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">変換の追加</translation>
     </message>
     <message>
         <source>Delete translation(translation_name):</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">変換を削除(変換名):</translation>
     </message>
     <message>
         <source>Delete translation</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">変換を削除</translation>
     </message>
     <message>
         <source>Modify translation(translation_name):</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">変換を変更(変換名):</translation>
     </message>
     <message>
         <source>Modify translation</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">変換を変更</translation>
     </message>
     <message>
         <source>close</source>
@@ -1508,4 +1641,96 @@ Do you want to save your changes?</source>
         <translation type="unfinished">閉じる</translation>
     </message>
 </context>
+<context>
+    <name>Useradd</name>
+    <message>
+        <source>useradd</source>
+        <translation type="obsolete">ユーザの追加</translation>
+    </message>
+    <message>
+        <source>User name:</source>
+        <translation type="unfinished">ユーザ名</translation>
+    </message>
+    <message>
+        <source>Password:</source>
+        <translation type="unfinished">パスワード</translation>
+    </message>
+    <message>
+        <source>Password again:</source>
+        <translation type="unfinished">もう一度パスワードを</translation>
+    </message>
+    <message>
+        <source></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;useradd</source>
+        <translation type="obsolete">ユーザの追加</translation>
+    </message>
+    <message>
+        <source>&amp;Close</source>
+        <translation type="unfinished">閉じる</translation>
+    </message>
+    <message>
+        <source>segatex alert</source>
+        <translation type="unfinished">segatexアラート</translation>
+    </message>
+    <message>
+        <source>No username given.
+Try again !</source>
+        <translation type="unfinished">ユーザ名が空欄です！</translation>
+    </message>
+    <message>
+        <source>Password does not match.
+Try again !</source>
+        <translation type="unfinished">パスワードが一致しません。
+もう一度やってください。</translation>
+    </message>
+    <message>
+        <source>Ooops! Password is empty.
+Try again !</source>
+        <translation type="unfinished">パスワード欄が空です。もう一度！</translation>
+    </message>
+    <message>
+        <source>
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>useradd process had an error !</source>
+        <translation type="unfinished">ユーザ追加過程でエラーがありました！</translation>
+    </message>
+    <message>
+        <source>manage user</source>
+        <translation type="unfinished">ユーザ操作</translation>
+    </message>
+    <message>
+        <source>user&amp;add</source>
+        <translation type="unfinished">ユーザの追加</translation>
+    </message>
+    <message>
+        <source>user&amp;del</source>
+        <translation type="unfinished">ユーザの削除</translation>
+    </message>
+    <message>
+        <source>read /etc/passwd</source>
+        <translation type="unfinished">/etc/passwdを読む</translation>
+    </message>
+    <message>
+        <source>You can&apos;t delete user root.
+Try again !</source>
+        <translation type="unfinished">rootは削除できません！もう一度！</translation>
+    </message>
+</context>
+<context>
+    <name>UseraddProcess</name>
+    <message>
+        <source>close</source>
+        <translation type="obsolete">閉じる</translation>
+    </message>
+    <message>
+        <source>useradd process had an error !</source>
+        <translation type="obsolete">ユーザ追加過程でエラーがありました！</translation>
+    </message>
+</context>
 </TS>
