@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007 Shintaro Fujiwara 
+ * Copyright (C) 2007-2008 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1340,16 +1340,7 @@ lines_break.gres(" socket_class_set","{ tcp_socket udp_socket rawip_socket netli
 lines_break.gres(" dgram_socket_class_set","{ udp_socket unix_dgram_socket }");
 lines_break.gres(" stream_socket_class_set","{ tcp_socket unix_stream_socket }");
 lines_break.gres(" unpriv_socket_class_set","{ tcp_socket udp_socket unix_stream_socket unix_dgram_socket }");
-lines_break.gres(" stat_file_perms","{ getattr }");
-lines_break.gres(" x_file_perms","{ getattr execute }");
-lines_break.gres(" r_file_perms","{ read getattr lock ioctl }");
-lines_break.gres(" rx_file_perms","{ read getattr lock execute ioctl }");
-lines_break.gres(" ra_file_perms","{ ioctl read getattr lock append }");
-lines_break.gres(" link_file_perms","{ getattr link unlink rename }");
-lines_break.gres(" create_lnk_perms","{ create read getattr setattr link unlink rename }");
-lines_break.gres(" r_dir_perms","{ read getattr lock search ioctl }");
 lines_break.gres(" rw_dir_perms","{ read getattr lock search ioctl add_name remove_name write }");
-lines_break.gres(" ra_dir_perms","{ read getattr lock search ioctl add_name write } ");
 lines_break.gres(" mount_fs_perms","{ mount remount unmount getattr }");
 lines_break.gres(" rw_socket_perms","{ ioctl read getattr write setattr append bind connect getopt setopt shutdown }");
 lines_break.gres(" create_socket_perms","{ create rw_socket_perms }");
@@ -1387,7 +1378,7 @@ lines_break.gres(" relabel_dir_perms","{ getattr relabelfrom relabelto }");
 lines_break.gres(" getattr_file_perms","{ getattr }");
 lines_break.gres(" setattr_file_perms","{ setattr }");
 lines_break.gres(" read_file_perms","{ getattr read lock ioctl }");
-lines_break.gres(" mmap_file_perms","{ getattr read execute }");
+lines_break.gres(" mmap_file_perms","{ getattr read execute ioctl }");
 lines_break.gres(" exec_file_perms","{ getattr read execute execute_no_trans }");
 lines_break.gres(" append_file_perms","{ getattr append lock ioctl }");
 lines_break.gres(" write_file_perms","{ getattr write append lock ioctl }");
@@ -1465,7 +1456,6 @@ lines_break.gres(" relabel_chr_file_perms","{ getattr relabelfrom relabelto }");
 lines_break.gres(" rw_term_perms","{ getattr read write ioctl }");
 lines_break.gres(" client_stream_socket_perms","{ create ioctl read getattr write setattr append bind getopt setopt shutdown }");
 lines_break.gres(" server_stream_socket_perms","{ client_stream_socket_perms listen accept }");
-				
 				lines_break.sort();
 				//meke it unique there is no unique function, so...
 				QTextStream stream_w( &file_w );
