@@ -187,7 +187,7 @@ QRegExp rx_apache_run_helper("apache_run_helper");
 QRegExp rx_apache_run_all_scripts("apache_run_all_scripts");
 QRegExp rx_apache_cgi_domain("apache_cgi_domain");
 QRegExp rx_bind_run_ndc("bind_run_ndc");
-QRegExp rx_bluetooth_run_helper("bluetooth_run_helper");
+///////QRegExp rx_bluetooth_run_helper("bluetooth_run_helper");
 QRegExp rx_clockspeed_run_cli("clockspeed_run_cli");
 QRegExp rx_cron_system_entry("cron_system_entry");
 QRegExp rx_dcc_run_cdcc("dcc_run_cdcc");
@@ -240,7 +240,7 @@ QRegExp rx_init_domain("init_domain");
 QRegExp rx_init_ranged_domain("init_ranged_domain");
 QRegExp rx_init_daemon_domain("init_daemon_domain");
 QRegExp rx_init_ranged_daemon_domain("init_ranged_daemon_domain");
-QRegExp rx_init_system_domain("init_system_domain");
+///////QRegExp rx_init_system_domain("init_system_domain");
 QRegExp rx_init_ranged_system_domain("init_ranged_system_domain");
 QRegExp rx_init_script_file_domtrans("init_script_file_domtrans");
 QRegExp rx_init_run_daemon("init_run_daemon");
@@ -248,16 +248,20 @@ QRegExp rx_init_script_tmp_filetrans("init_script_tmp_filetrans");
 QRegExp rx_ipsec_run_setkey("ipsec_run_setkey");
 QRegExp rx_iptables_run("iptables_run");
 QRegExp rx_libs_run_ldconfig("libs_run_ldconfig");
-QRegExp rx_lib_filetrans_shared_lib("lib_filetrans_shared_lib");
-QRegExp rx_files_lib_filetrans_shared_lib("files_lib_filetrans_shared_lib");
+///////QRegExp rx_lib_filetrans_shared_lib("lib_filetrans_shared_lib");
+///////QRegExp rx_files_lib_filetrans_shared_lib("files_lib_filetrans_shared_lib");
 QRegExp rx_logging_run_auditctl("logging_run_auditctl");
 QRegExp rx_logging_run_auditd("logging_run_auditd");
 QRegExp rx_logging_log_filetrans("logging_log_filetrans");
+///////new20080402
+QRegExp rx_logging_log_admin("logging_log_admin");
 QRegExp rx_lvm_run("lvm_run");
 QRegExp rx_modutils_run_insmod("modutils_run_insmod");
 QRegExp rx_modutils_run_depmod("modutils_run_depmod");
 QRegExp rx_modutils_run_update_mods("modutils_run_update_mods");
 QRegExp rx_mount_run("mount_run");
+///////new20080402
+QRegExp rx_mount_run_unconfined("mount_run_unconfined");
 QRegExp rx_netlabel_run_mgmt("netlabel_run_mgmt");
 QRegExp rx_pcmcia_run_cardctl("pcmcia_run_cardctl");
 QRegExp rx_seutil_run_checkpolicy("seutil_run_checkpolicy");
@@ -272,6 +276,10 @@ QRegExp rx_sysnet_run_dhcpc("sysnet_run_dhcpc");
 QRegExp rx_sysnet_run_ifconfig("sysnet_run_ifconfig");
 QRegExp rx_sysnet_dhcp_state_filetrans("sysnet_dhcp_state_filetrans");
 QRegExp rx_unconfined_run("unconfined_run");
+///////new20080402
+QRegExp rx_unconfined_domtrans_to("unconfined_domtrans_to");
+///////new20080402
+QRegExp rx_unconfined_run_to("unconfined_run_to");
 QRegExp rx_userdom_sysadm_home_dir_filetrans("userdom_sysadm_home_dir_filetrans");
 QRegExp rx_userdom_generic_user_home_dir_filetrans_generic_user_home_content("userdom_generic_user_home_dir_filetrans_generic_user_home_content");
 
@@ -464,7 +472,7 @@ QRegExp rx_userdom_generic_user_home_dir_filetrans_generic_user_home_content("us
 (line_analized.find( rx_apache_run_all_scripts, 0) != -1)||
 (line_analized.find( rx_apache_cgi_domain, 0) != -1)||
 (line_analized.find( rx_bind_run_ndc, 0) != -1)||
-(line_analized.find( rx_bluetooth_run_helper, 0) != -1)||
+/////(line_analized.find( rx_bluetooth_run_helper, 0) != -1)||
 (line_analized.find( rx_clockspeed_run_cli, 0) != -1)||
 (line_analized.find( rx_cron_system_entry, 0) != -1)||
 (line_analized.find( rx_dcc_run_cdcc, 0) != -1)||
@@ -517,7 +525,7 @@ QRegExp rx_userdom_generic_user_home_dir_filetrans_generic_user_home_content("us
 (line_analized.find( rx_init_ranged_domain, 0) != -1)||
 (line_analized.find( rx_init_daemon_domain, 0) != -1)||
 (line_analized.find( rx_init_ranged_daemon_domain, 0) != -1)||
-(line_analized.find( rx_init_system_domain, 0) != -1)||
+/////(line_analized.find( rx_init_system_domain, 0) != -1)||
 (line_analized.find( rx_init_ranged_system_domain, 0) != -1)||
 (line_analized.find( rx_init_script_file_domtrans, 0) != -1)||
 (line_analized.find( rx_init_run_daemon, 0) != -1)||
@@ -525,8 +533,8 @@ QRegExp rx_userdom_generic_user_home_dir_filetrans_generic_user_home_content("us
 (line_analized.find( rx_ipsec_run_setkey, 0) != -1)||
 (line_analized.find( rx_iptables_run, 0) != -1)||
 (line_analized.find( rx_libs_run_ldconfig, 0) != -1)||
-(line_analized.find( rx_lib_filetrans_shared_lib, 0) != -1)||
-(line_analized.find( rx_files_lib_filetrans_shared_lib, 0) != -1)||
+/////(line_analized.find( rx_lib_filetrans_shared_lib, 0) != -1)||
+/////(line_analized.find( rx_files_lib_filetrans_shared_lib, 0) != -1)||
 (line_analized.find( rx_logging_run_auditctl, 0) != -1)||
 (line_analized.find( rx_logging_run_auditd, 0) != -1)||
 (line_analized.find( rx_logging_log_filetrans, 0) != -1)||
