@@ -196,9 +196,6 @@ void SemanageCoreFcontextProcess::modify_button_clicked()
 /* this slot does just make .pp file */
 void SemanageCoreFcontextProcess::add_button_clicked_process(QString semanageEditLineEdit_str, QString semanageEditLineEdit2_str, QString semanageEditLineEdit7_str)
 {
-	//QRegExp rx_path("/[a-zA-Z]+");
-	//int i = string.find( QRegExp("an"), 0 );    // i == 1
-	//int i = semanageEditLineEdit2_str.find( QRegExp("[/a-zA-Z0-9]+"), 0 );    // i == 1
 	semanageEditLineEdit2_str_for_check = semanageEditLineEdit2_str;
 	semanageEditLineEdit2_str_for_check.replace( QChar('"'), "" );
 	s_first = semanageEditLineEdit2_str_for_check.section('/', 1, 1 );
@@ -641,14 +638,6 @@ void SemanageCoreFcontextProcess::readFromOutputFile()
 			name = *it_d;
 			file_interface_name = dir_name + forward_slash + name;
 			QFile file( file_interface_name );
-			/*
-			QRegExp rx_nologin("nologin");
-			QRegExp rx_shutdown("shutdown");
-			QRegExp rx_halt("halt");
-			QRegExp rx_news("news");
-			QRegExp rx_false("false");
-			QRegExp rx_sync("sync");
-			*/
 			if ( file.open( IO_ReadOnly ) ) {
 				QTextStream stream( &file );
 				////////////////////////////////////////////
@@ -656,31 +645,11 @@ void SemanageCoreFcontextProcess::readFromOutputFile()
 				if(order_x == 1)
 					textEdit1->append("#########fcontext list#########");
 					textEdit1->append("");
-				/*
-				if(order_x == 2)
-					textEdit1->append("#########user list#########");
-					textEdit1->append("");
-				if(order_x == 3)
-					textEdit1->append("#########etc passwd list#########");
-					textEdit1->append("");
-				*/
 				while ( !stream.atEnd() ) {
 					line_analized = stream.readLine(); // line of text excluding '\n'
-					//buttons.push_back(line_analized);
-					/*
-					i = line_analized.find( rx_nologin, 0);
-					j = line_analized.find( rx_shutdown, 0);
-					k = line_analized.find( rx_halt, 0);
-					l = line_analized.find( rx_news, 0);
-					m = line_analized.find( rx_false, 0);
-					n = line_analized.find( rx_sync, 0);
-					*/
-                                        //if((i != -1)||(j != -1)||(k != -1)||(l != -1)||(m != -1)||(n != -1)){
-						//do nothing
-					//}else{
-						textEdit1->append(line_analized);
-					//}
+					textEdit1->append(line_analized);
 				}
+				textEdit1->setCursorPosition(0,0);
 				file.close();
 				order_x++;
 				++it_d;
